<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Carbon\Carbon;

class Course extends Model
{
    protected $fillable = [
        'subject_id',
        'course_code',
        'course_title',
        'description',
        'coefficient',
        'hourly_volume',
        'grade_id',
        'grade_title',
        'weekday',
        'start_time',
        'end_time',
        'classe_id',
        'professor_id',
        'professor_name',
        'professor_firstname',
        'professor_email',
        'professor_phone',
        'professor_address',
        'professor_profession',
    ];

    const WEEK_DAYS = [
        '1' => 'Monday',
        '2' => 'Tuesday',
        '3' => 'Wednesday',
        '4' => 'Thursday',
        '5' => 'Friday',
        '6' => 'Saturday',
        '7' => 'Sunday',
    ];

    public function getDifferenceAttribute()
    {
        return Carbon::parse($this->end_time)->diffInMinutes($this->start_time);
    }

    public function getStartTimeAttribute($value)
    {
        return $value ? Carbon::createFromFormat('H:i:s', $value)->format(config('panel.lesson_time_format')) : null;
    }

    public function setStartTimeAttribute($value)
    {
        $this->attributes['start_time'] = $value ? Carbon::createFromFormat(config('panel.lesson_time_format'),
            $value)->format('H:i:s') : null;
    }

    public function getEndTimeAttribute($value)
    {
        return $value ? Carbon::createFromFormat('H:i:s', $value)->format(config('panel.lesson_time_format')) : null;
    }

    public function setEndTimeAttribute($value)
    {
        $this->attributes['end_time'] = $value ? Carbon::createFromFormat(config('panel.lesson_time_format'),
            $value)->format('H:i:s') : null;
    }

    function subject()
    {
        return $this->belongsTo(Subject::class, 'subject_id');
    }

    function classe()
    {
        return $this->belongsTo(Classe::class, 'classe_id');
    }

    function grade()
    {
        return $this->belongsTo(Grade::class, 'grade_id');
    }

    public function professor()
    {
        return $this->belongsTo(Professor::class, 'professor_id');
    }

    public static function isTimeAvailable($weekday, $startTime, $endTime, $classe, $professor, $course)
    {
        $courses = self::where('weekday', $weekday)
            ->when($course, function ($query) use ($course) {
                $query->where('id', '!=', $course);
            })
            ->where(function ($query) use ($classe, $professor) {
                $query->where('classe_id', $classe)
                    ->orWhere('professor_id', $professor);
            })
            ->where([
                ['start_time', '<', $endTime],
                ['end_time', '>', $startTime],
            ])
            ->count();

        return !$courses;
    }


    public function scopeCalendarByRoleOrClassId($query)
    {
        return $query->when(!request()->input('class_id'), function ($query) {
            $query->when(auth()->user()->is_professor, function ($query) {
                $query->where('professor_id', auth()->user()->id);
            })
                ->when(auth()->user()->is_student, function ($query) {
                    $query->where('classe_id', auth()->user()->classe_id ?? '0');
                })

                ->when(auth()->user()->is_parent, function ($query) {
                    $query->where('classe_id', request()->input('classe_id'));
                });
        })
            ->when(request()->input('classe_id'), function ($query) {
                $query->where('classe_id', request()->input('classe_id'));
            });
    }
}
