<?php

namespace App\Http\Controllers;

use App\Company;
use App\Historique;
use Illuminate\Http\Request;

class ConfigurationController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('configurations.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //Validate name, email and password fields
        $this->validate($request, [
            'company_name' => 'required|max:120',
            'contact_person' => 'required|max:120',
            'email' => 'required|email|unique:configurations',
            'address' => 'required',
            'phone_number' => 'required',
            'logo' => 'image|nullable',
        ]);

        if ($request->hasfile('logo')) {
            // Get filename with the extension
            $fileNameWithExt = $request->file('logo')->getClientOriginalName();

            // Get just filename
            $filename = pathinfo($fileNameWithExt, PATHINFO_FILENAME);

            // Get just ext
            $extension = $request->file('logo')->getClientOriginalExtension();

            // Filename to store
            $fileNameToStore = $filename.'_'.time().'.'.$extension;

            // Upload Image
            $path = $request->file('logo')->storeAs('public/cover_images', $fileNameToStore);
        } else {
            $fileNameToStore = 'noimage.jpg';
        }

        $company= new Company();
        $company->company_name = $request->input('company_name');
        $company->contact_person = $request->input('contact_person');
        $company->acronym = $request->input('acronym');
        $company->slogan = $request->input('slogan');
        $company->email = $request->input('email');
        $company->phone_number = $request->input('phone_number');
        $company->mobile_number = $request->input('mobile_number');
        $company->fax = $request->input('fax');
        $company->address = $request->input('address');
        $company->url = $request->input('url');
        $company->logo = $fileNameToStore;

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Company';
        $historique->user_id = auth()->user()->id;


        $company->save();
        $historique->save();

        //Redirect to the configurations.index view and display message
        return redirect()->route('configurations.create')
            ->with('success',
             'Configuration reussie!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
