<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Course;
use App\Subject;
use App\Classe;
use App\Professor;
use App\Historique;
use Carbon\Carbon;

class CourseController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all courses  and pass it to the view
        $courses = Course::all();

        return view('courses.index')->with('courses', $courses);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $classes = Classe::pluck('classe_code', 'id');

        $subjects = Subject::pluck('title', 'id');

        $professors = Professor::pluck('name','id' );

        return view('courses.create', compact('classes', 'subjects' ,'professors'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'weekday' => 'required',
            'start_time' => 'required',
            'end_time' => 'required',
            'classe_id' => 'required',
            'professor_id' => 'required',
        ]);

        $course = new Course();

        $course->weekday = $request->input('weekday');
        //$start = Carbon::parse($request->input('start_time'));
        //$end = Carbon::parse($request->input('end_time'));
        //$course->start_time = $start;
        //$course->end_time = $end;
        $course->start_time = $request->input('start_time');
        $course->end_time = $request->input('end_time');
        $course->subject_id = $request->input('subject_id');
        $course->classe_id = $request->input('classe_id');
        $course->professor_id = $request->input('professor_id');
        $course->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Course';
        $historique->user_id = auth()->user()->id;

        $course->save();
        $historique->save();

        //Redirect to the classes.index view and display message
        return redirect()->route('courses.index')
            ->with('success',
             'Nouvelle Matière ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $course = Course::findOrFail($id);

        $professors = Professor::pluck('name','id');

        $subjects = Subject::pluck('title', 'id');

        $classes = Classe::pluck('classe_code', 'id');

        return view('courses.edit', compact('course', 'classes', 'subjects' ,'professors')); //pass classe data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $course = Course::findOrFail($id);

        $this->validate($request, [
            'weekday' => 'required',
            'start_time' => 'required',
            'end_time' => 'required',
            'classe_id' => 'required',
            'professor_id' => 'required',
        ]);
        
        $course->weekday = $request->input('weekday');
        $course->start_time = $request->input('start_time');
        $course->end_time = $request->input('end_time');
        $course->subject_id = $request->input('subject_id');
        $course->classe_id = $request->input('classe_id');
        $course->professor_id = $request->input('professor_id');
        $course->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Course';
        $historique->user_id = auth()->user()->id;

        $course->save();

        $historique->save();

        //Redirect to the classes.index view and display message
        return redirect()->route('courses.index')
            ->with('success',
             'Cours édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $course = Course::findOrFail($id);

        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'Subject';
        $historique->user_id = auth()->user()->id;

        $historique->save();
        $course->delete();

        return redirect()->route('courses.index')
            ->with('success',
             'Cours supprimé avec succès.');
    }
}
