<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\AcademicYear;
use App\Student;
use App\Historique;
use App\Classe;
use App\Inscription;
use Carbon\Carbon;

class InscriptionController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all inscriptions  and pass it to the view
        $inscriptions = Inscription::all();

        return view('inscriptions.index')->with('inscriptions', $inscriptions);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $academicyears = AcademicYear::pluck('title', 'id');

        $classes = Classe::pluck('classe_code', 'id');

        $students = Student::pluck('name', 'id');

        $date = Carbon::now();

        return view('inscriptions.create', compact('academicyears','classes','students','date'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'academicyear_id' => 'required',
            'classe_id' => 'required',
        ]);

        $inscription = new Inscription();
        $inscription->date_entry = $request->input('date_entry');
        $inscription->academicyear_id = $request->input('academicyear_id');

        $academicyear = AcademicYear::findOrFail($inscription->academicyear_id);

        $inscription->academicyear_title = $academicyear->title;

        $inscription->classe_id = $request->input('classe_id');

        $classe = Classe::findOrFail($inscription->classe_id);

        $inscription->classe_code = $classe->classe_code;
        $inscription->classe_name = $classe->classe_name;
        $inscription->grade_id = $classe->grade_id;
        $inscription->grade_title = $classe->grade_title;

        $inscription->student_id = $request->input('student_id');

        $student = Student::findOrFail($inscription->student_id);

        $inscription->student_name = $student->name;
        $inscription->student_firstname = $student->firstname;
        $inscription->student_email = $student->email;
        $inscription->gender = $student->gender;
        $inscription->student_phone = $student->phone_number;
        $inscription->student_address = $student->address;
        $inscription->birth_date = $student->birth_date;
        $inscription->place_birth = $student->place_birth;
        $inscription->age = $student->age;

        $student->classe_id = $classe->id;
        $student->classe_code = $classe->classe_code;
        $student->classe_name = $classe->classe_name;
        $student->grade_id = $classe->grade_id;
        $student->grade_title = $classe->grade_title;

        $inscription->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Inscription';
        $historique->user_id = auth()->user()->id;

        $inscription->save();
        $student->save();
        $historique->save();

        //Redirect to the inscriptions.index view and display message
        return redirect()->route('inscriptions.index')
            ->with('success',
             'Nouvel Inscription effectué avec succès.');
        
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $inscription = Inscription::findOrFail($id);
        
        $academicyears = AcademicYear::pluck('title', 'id');

        $classes = Classe::pluck('classe_code', 'id');

        $students = Student::pluck('name', 'id');

        return view('inscriptions.edit', compact('inscription','academicyears','classes','students'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $inscription = Inscription::findOrFail($id);

        $this->validate($request, [
            'academicyear_id' => 'required',
            'classe_id' => 'required',
        ]);

        $inscription->date_entry = $request->input('date_entry');
        $inscription->academicyear_id = $request->input('academicyear_id');

        $academicyear = AcademicYear::findOrFail($inscription->academicyear_id);

        $inscription->academicyear_title = $academicyear->title;

        $inscription->classe_id = $request->input('classe_id');

        $classe = Classe::findOrFail($inscription->classe_id);

        $inscription->classe_code = $classe->classe_code;
        $inscription->classe_name = $classe->classe_name;
        $inscription->grade_id = $classe->grade_id;
        $inscription->grade_title = $classe->grade_title;

        $inscription->student_id = $request->input('student_id');

        $student = Student::findOrFail($inscription->student_id);

        $inscription->student_name = $student->name;
        $inscription->student_firstname = $student->firstname;
        $inscription->student_email = $student->email;
        $inscription->gender = $student->gender;
        $inscription->student_phone = $student->phone_number;
        $inscription->student_address = $student->address;
        $inscription->birth_date = $student->birth_date;
        $inscription->place_birth = $student->place_birth;
        $inscription->age = $student->age;

        $student->classe_id = $classe->id;
        $student->classe_code = $classe->classe_code;
        $student->classe_name = $classe->classe_name;
        $student->grade_id = $classe->grade_id;
        $student->grade_title = $classe->grade_title;

        $inscription->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Inscription';
        $historique->user_id = auth()->user()->id;

        $inscription->save();
        $student->save();
        $historique->save();

        //Redirect to the inscriptions.index view and display message
        return redirect()->route('inscriptions.index')
            ->with('success',
             'Inscription édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $inscription = Inscription::findOrFail($id);

        $inscription->delete();

        return redirect()->route('inscriptions.index')
            ->with('success',
             'Inscription supprimé avec succès.');
    }
}
