<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Note;
use App\Exam;
use App\Student;
use App\Historique;
use App\Classe;

class NoteController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all notes  and pass it to the view
        $notes = Note::all();

        return view('notes.index')->with('notes', $notes);
    }

    public function getClasse()
    {
        $classes = Classe::all(); //Get all classes

        return view('notes.checkclasse', compact('classes'));
    }

    public function addNote($id)
    {
        $classe = Classe::findOrFail($id);

        $exams = Exam::pluck('exam_title', 'id');

        $students  = $classe->students;

        return view('notes.create', compact('students', 'exams'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        /* $exams = Exam::pluck('exam_title', 'id');

        $students = Student::all();

        return view('notes.create', compact('exams','students')); */
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->all();

        $i = 0;

        foreach($data['student_id'] as $item){
            
            $note = new Note();
            $note->student_id = $item;
            $student = Student::findOrFail($item);

            $note->student_name = $student->name;
            $note->student_firstname = $student->firstname;
            $note->student_mark = $data['student_mark'][$i];
            $note->exam_id = $data['exam_id'][$i];
            $exam = Exam::findOrFail($note->exam_id);
            $note->exam_notation = $exam->notation;
            $note->exam_title = $exam->exam_title;
            $note->exam_period = $exam->period;
            $note->date_exam = $exam->date_exam;
            $note->professor_id = $exam->professor_id;
            $note->user_id = auth()->user()->id;

            $note->save();
            $i++;
        }

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Notes';
        $historique->user_id = auth()->user()->id;

        $historique->save();

        //Redirect to the notes.index view and display message
        return redirect()->route('notes.index')
            ->with('success',
             'Note(s) reporté(s) avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $note = Note::findOrFail($id);

        $note->delete();

        return redirect()->route('notes.index')
            ->with('success',
             'Note supprimé avec succès.');
    }
}
