<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\User;
use App\Professor;
use App\Historique;

class ProfessorController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all professors  and pass it to the view
        $professors = Professor::all();

        return view('professors.index')->with('professors', $professors);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('professors.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //Validate name, email and password fields
        $this->validate($request, [
            'name' => 'required|max:120',
            'firstname' => 'required|max:120',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:6|confirmed',
            'address' => 'required',
            'profile_picture' => 'image|nullable',
        ]);

        if ($request->hasfile('profile_picture')) {
            // Get filename with the extension
            $fileNameWithExt = $request->file('profile_picture')->getClientOriginalName();

            // Get just filename
            $filename = pathinfo($fileNameWithExt, PATHINFO_FILENAME);

            // Get just ext
            $extension = $request->file('profile_picture')->getClientOriginalExtension();

            // Filename to store
            $fileNameToStore = $filename.'_'.time().'.'.$extension;

            // Upload Image
            $path = $request->file('profile_picture')->storeAs('public/cover_images', $fileNameToStore);
        } else {
            $fileNameToStore = 'noimage.jpg';
        }

        $professor= new Professor();
        $professor->name = $request->input('name');
        $professor->firstname = $request->input('firstname');
        $professor->email = $request->input('email');
        $professor->gender = $request->input('gender');
        $professor->profile_picture = $fileNameToStore;
        $professor->phone_number = $request->input('phone_number');
        $professor->address = $request->input('address');
        $professor->birth_date = $request->input('birth_date');
        $professor->place_birth = $request->input('place_birth');
        $professor->marital_status = $request->input('marital_status');
        $professor->nationality = $request->input('nationality');
        $professor->hired_date = $request->input('hired_date');
        $professor->profession = $request->input('profession');
        $professor->age = $request->input('age');
        $professor->create_user_id = auth()->user()->id;

        $user = new User();
        $user->name = $request->input('name');
        $user->firstname = $request->input('firstname');
        $user->email = $request->input('email');
        $user->password = $request->input('password');
        $user->profile_picture = $fileNameToStore;
        $user->phone_number = $request->input('phone_number');
        $user->address = $request->input('address');
        $user->role_id = 2;


        $professor->save();
        $user->save();

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'User/Professor';
        $historique->user_id = auth()->user()->id;

        $professor = Professor::findOrFail($professor->id);
        $professor->user_id = $user->id;

        $professor->save();
        $historique->save();

        //Redirect to the professors.index view and display message
        return redirect()->route('professors.index')
            ->with('success',
             'Nouveau Professeur ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $professor = Professor::findOrFail($id); 

        return view('professors.edit', compact('professor')); //pass professor data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $professor = Professor::findOrFail($id); //Get role specified by id

        //Validate name, email and password fields
        $this->validate($request, [
            'name' => 'required|max:120',
            'firstname' => 'required|max:120',
            'email' => 'required|email|unique:professors,email,'.$id,
            'password' => 'required|min:6|confirmed',
            'phone_number' => 'required',
            'address' => 'required',
            'profile_picture' => 'image|nullable',
        ]);

        if ($request->hasfile('profile_picture')) {
            // Get filename with the extension
            $fileNameWithExt = $request->file('profile_picture')->getClientOriginalName();

            // Get just filename
            $filename = pathinfo($fileNameWithExt, PATHINFO_FILENAME);

            // Get just ext
            $extension = $request->file('profile_picture')->getClientOriginalExtension();

            // Filename to store
            $fileNameToStore = $filename.'_'.time().'.'.$extension;

            // Upload Image
            $path = $request->file('profile_picture')->storeAs('public/cover_images', $fileNameToStore);
        } else {
            $fileNameToStore = 'noimage.jpg';
        }

        $professor->name = $request->input('name');
        $professor->firstname = $request->input('firstname');
        $professor->email = $request->input('email');
        $professor->gender = $request->input('gender');
        if ($request->hasfile('profile_picture')) {
            $professor->profile_picture = $fileNameToStore;
        }
        $professor->phone_number = $request->input('phone_number');
        $professor->address = $request->input('address');
        $professor->birth_date = $request->input('birth_date');
        $professor->place_birth = $request->input('place_birth');
        $professor->marital_status = $request->input('marital_status');
        $professor->nationality = $request->input('nationality');
        $professor->hired_date = $request->input('hired_date');
        $professor->profession = $request->input('profession');
        $professor->age = $request->input('age');
        $professor->create_user_id = auth()->user()->id;
        
        $user = User::findOrFail($professor->user_id);

        $user->name = $request->input('name');
        $user->firstname = $request->input('firstname');
        $user->email = $request->input('email');
        $user->password = $request->input('password');
        $user->phone_number = $request->input('phone_number');
        $user->address = $request->input('address');
        if ($request->hasfile('profile_picture')) {
            $user->profile_picture = $fileNameToStore;
        }
        
        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'User/Professor';
        $historique->user_id = auth()->user()->id;
        
        $professor->save();
        $user->save();
		$historique->save();

        return redirect()->route('professors.index')
            ->with('success',
             'Professeur '.$professor->name.' edité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $professor = Professor::findOrFail($id);
        $user = User::findOrFail($professor->user_id);

        if ($user->profile_picture != 'noimage.jpg') {
            Storage::delete('public/cover_images/'.$user->profile_picture);
        }

        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'User/Professor';
        $historique->user_id = auth()->user()->id;

        $user->delete();
        $professor->delete();
        $historique->save();

        return redirect()->route('professors.index')
            ->with('success',
             'Professeur supprimé avec succès.');
    }
}
