<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Subject;
use App\Grade;
use App\Professor;
use App\Historique;

class SubjectController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all subjects  and pass it to the view
        $subjects = Subject::all();

        return view('subjects.index')->with('subjects', $subjects);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $grades = Grade::pluck('title', 'id');

        return view('subjects.create', compact('grades'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'course_code' => 'required',
            'course_title' => 'required',
            'grade_id' => 'required',
        ]);

        $subject = new Subject();
        $subject->code = $request->input('course_code');
        $subject->title = $request->input('course_title');
        $subject->coefficient = $request->input('coefficient');
        $subject->hourly_volume = $request->input('hourly_volume');
        $subject->grade_id = $request->input('grade_id');
        $subject->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Subject';
        $historique->user_id = auth()->user()->id;

        $subject->save();
        $historique->save();

        //Redirect to the subjects.index view and display message
        return redirect()->route('subjects.index')
            ->with('success',
             'Nouvelle Matière ajoutée avec succès.');
        
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
       $subject = Subject::findOrFail($id);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $subject = Subject::findOrFail($id);

        $grades = Grade::pluck('title', 'id');

        return view('courses.edit', compact('subject', 'grades')); //pass classe data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {

        $subject = Subject::findOrFail($id);

        $this->validate($request, [
            'course_code' => 'required',
            'course_title' => 'required',
            'grade_id' => 'required',
        ]);

        $subject->code = $request->input('course_code');
        $subject->title = $request->input('course_title');
        $subject->coefficient = $request->input('coefficient');
        $subject->hourly_volume = $request->input('hourly_volume');
        $subject->grade_id = $request->input('grade_id');
        $subject->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Subject';
        $historique->user_id = auth()->user()->id;

        $subject->save();
        $historique->save();

        //Redirect to the subjects.index view and display message
        return redirect()->route('subjects.index')
            ->with('success',
             'Matière éditée avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $subject = Subject::findOrFail($id);
        
        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'Subject';
        $historique->user_id = auth()->user()->id;

        $historique->save();
        $subject->delete();

        return redirect()->route('courses.index')
            ->with('success',
             'Matière supprimée avec succès.');
    }
}
