<?php

namespace App;

use Laravel\Passport\HasApiTokens;
use Illuminate\Notifications\Notifiable;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Support\Facades\Hash;
use Spatie\Permission\Traits\HasRoles;

class User extends Authenticatable
{
    use HasRoles,Notifiable,HasApiTokens;

    protected $guard_name = 'web';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name', 'firstname','email', 'password','phone_number', 'address',
    ];

    public function setPasswordAttribute($password)
    {
        $this->attributes['password'] = Hash::needsRehash($password) ? Hash::make($password) : $password;
    }

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    /*public function getIsAdminAttribute()
    {
        return $this->roles()->where('id', 1)->exists();
    }*/

    public function getIsStudentAttribute()
    {
        return self::where('id', $this->id)->where('id', 1)->exists();
    }

    public function getIsProfessorAttribute()
    {
        return self::where('id', $this->id)->where('id', 2)->exists();
    }
    
    public function getIsParentAttribute()
    {
        return self::where('id', $this->id)->where('id', 3)->exists();
    }

    public function classe()
    {
        return $this->belongsTo(Classe::class, 'classe_id');
    }
}
